@@ -13,32 +13,17 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from oslo_config import cfg
-
-from zaqar import storage
-
-_CONFIG_GROUP = 'drivers:message_store:faulty'
+from zaqar.queues import storage
 
 
 class DataDriver(storage.DataDriverBase):
-
-    _DRIVER_OPTIONS = [(_CONFIG_GROUP,
-                        [cfg.StrOpt('uri', default='faulty://')])]
-
-    def __init__(self, conf, cache, control_driver):
-        super(DataDriver, self).__init__(conf, cache, control_driver)
-
-    def close(self):
-        pass
+    def __init__(self, conf, cache):
+        super(DataDriver, self).__init__(conf, cache)
 
     @property
     def default_options(self):
         return {}
 
-    @property
-    def capabilities(self):
-        raise NotImplementedError()
-
     def is_alive(self):
         raise NotImplementedError()
 
@@ -47,7 +32,7 @@ class DataDriver(storage.DataDriverBase):
 
     @property
     def queue_controller(self):
-        return self.control_driver.queue_controller
+        return QueueController(self)
 
     @property
     def message_controller(self):
@@ -57,27 +42,12 @@ class DataDriver(storage.DataDriverBase):
     def claim_controller(self):
         return None
 
-    @property
-    def subscription_controller(self):
-        return None
-
-    @property
-    def topic_controller(self):
-        return self.control_driver.topic_controller
-
 
 class ControlDriver(storage.ControlDriverBase):
 
     def __init__(self, conf, cache):
         super(ControlDriver, self).__init__(conf, cache)
 
-    def close(self):
-        pass
-
-    @property
-    def queue_controller(self):
-        return QueueController(self)
-
     @property
     def catalogue_controller(self):
         return None
@@ -90,37 +60,33 @@ class ControlDriver(storage.ControlDriverBase):
     def flavors_controller(self):
         return None
 
-    @property
-    def topic_controller(self):
-        return TopicController(self)
-
 
 class QueueController(storage.Queue):
     def __init__(self, driver):
         pass
 
-    def _list(self, project=None):
+    def list(self, project=None):
         raise NotImplementedError()
 
-    def _get(self, name, project=None):
+    def get(self, name, project=None):
         raise NotImplementedError()
 
     def get_metadata(self, name, project=None):
         raise NotImplementedError()
 
-    def _create(self, name, metadata=None, project=None):
+    def create(self, name, metadata=None, project=None):
         raise NotImplementedError()
 
-    def _exists(self, name, project=None):
+    def exists(self, name, project=None):
         raise NotImplementedError()
 
     def set_metadata(self, name, metadata, project=None):
         raise NotImplementedError()
 
-    def _delete(self, name, project=None):
+    def delete(self, name, project=None):
         raise NotImplementedError()
 
-    def _stats(self, name, project=None):
+    def stats(self, name, project=None):
         raise NotImplementedError()
 
 
@@ -150,34 +116,5 @@ class MessageController(storage.Message):
     def delete(self, queue, message_id, project=None, claim=None):
         raise NotImplementedError()
 
-    def bulk_delete(self, queue, message_ids, project=None, claim_ids=None):
-        raise NotImplementedError()
-
-
-class TopicController(storage.Topic):
-    def __init__(self, driver):
-        pass
-
-    def _list(self, project=None):
-        raise NotImplementedError()
-
-    def _get(self, name, project=None):
-        raise NotImplementedError()
-
-    def get_metadata(self, name, project=None):
-        raise NotImplementedError()
-
-    def _create(self, name, metadata=None, project=None):
-        raise NotImplementedError()
-
-    def _exists(self, name, project=None):
-        raise NotImplementedError()
-
-    def set_metadata(self, name, metadata, project=None):
-        raise NotImplementedError()
-
-    def _delete(self, name, project=None):
-        raise NotImplementedError()
-
-    def _stats(self, name, project=None):
+    def bulk_delete(self, queue, message_ids, project=None):
         raise NotImplementedError()
